@@ -1,5 +1,8 @@
 rforcecom.create <- 
 function(session, objectName, fields){
+ # Load packages
+ require(XML)
+ require(RCurl)
  
  # Create XML node set
  rforcecom.create.createXmlNodeSet <- function(nodelist){
@@ -43,9 +46,11 @@ function(session, objectName, fields){
  x.root <- xmlRoot(xmlTreeParse(t$value(), asText=T))
  
  # Check whether it success
+ errorcode <- NA
+ errormessage <- NA
  try(errorcode <- iconv(xmlValue(x.root[['Error']][['errorCode']]), from="UTF-8", to=""), TRUE)
  try(errormessage <- iconv(xmlValue(x.root[['Error']][['message']]), from="UTF-8", to=""), TRUE)
- if(errorcode != "NA" && errormessage != "NA"){
+ if(!is.na(errorcode) && !is.na(errormessage)){
   stop(paste(errorcode, errormessage, sep=": "))
  }
  
