@@ -1,5 +1,9 @@
 rforcecom.search <-
 function(session, queryString){
+ # Load packages
+ require(XML)
+ require(RCurl)
+ 
  # Retrieve XML via REST API
  h <- basicHeaderGatherer()
  t <- basicTextGatherer()
@@ -25,9 +29,11 @@ function(session, queryString){
   x.root <- xmlRoot(xmlTreeParse(t$value(), asText=T))
   
   # Check whether it success
+  errorcode <- NA
+  errormessage <- NA
   try(errorcode <- iconv(xmlValue(x.root[['Error']][['errorCode']]), from="UTF-8", to=""), TRUE)
   try(errormessage <- iconv(xmlValue(x.root[['Error']][['message']]), from="UTF-8", to=""), TRUE)
-  if(errorcode != "NA" && errormessage != "NA"){
+  if(!is.na(errorcode) && !is.na(errormessage)){
    stop(paste(errorcode, errormessage, sep=": "))
   }
  }
